@@ -142,6 +142,21 @@ class ExecutionSequence(ThreadedTrackedAction):
             **self.kwargs,
         )
 
+    def as_dict(self) -> dict:
+        """extra type cast for arguments"""
+        dct = super(ExecutionSequence, self).as_dict()
+        del dct['arguments']
+        dct['triggered'] = self.triggered
+        if self.triggered is True:
+            actions = self.args
+        else:
+            actions = self.configuration.action_sequence
+        dct['actions'] = [
+            action.as_dict() for action in actions
+        ]
+        # todo decide how to include relative start times
+        return dct
+
     @property
     @ensure_triggered
     def action_returns(self) -> dict:
