@@ -284,8 +284,6 @@ class ActionTimePoint(TimePoint, ExecutionSequence):
 
     def as_dict(self) -> dict:
         """Returns a key: value representation of the instance"""
-        dct = super(ActionTimePoint, self).as_dict()
         # todo decide how to include relative start times
-        dct['configuration'] = dct['configuration']['name']  # todo remove when legacy requirements are updated
-        return dct
+        return super(ActionTimePoint, self).as_dict()
 
